@@ -25,6 +25,7 @@ from urllib.parse import quote_plus, urlunsplit
 
 import pymongo
 from pymongo import MongoClient, ReplaceOne
+from pymongo.errors import CollectionInvalid
 
 from airflow.exceptions import AirflowConfigException
 from airflow.hooks.base import BaseHook
@@ -225,6 +226,37 @@ class MongoHook(BaseHook):
 
         return mongo_conn.get_database(mongo_db).get_collection(mongo_collection)
 
+    def create_collection(
+        self,
+        mongo_collection: str,
+        mongo_db: str | None = None,
+        return_if_exists: bool = True,
+        **create_kwargs: Any,
+    ) -> MongoCollection:
+        """
+        Create the collection (optionally a time‑series collection) and return it.
+
+        https://pymongo.readthedocs.io/en/stable/api/pymongo/database.html#pymongo.database.Database.create_collection
+
+        :param mongo_collection: Name of the collection.
+        :param mongo_db: Target database; defaults to the schema in the connection string.
+        :param return_if_exists: If True and the collection already exists, return it instead of raising.
+        :param create_kwargs: Additional keyword arguments forwarded to ``db.create_collection()``,
+                                  e.g. ``timeseries={...}``, ``capped=True``.
+        """
+        mongo_db = mongo_db or self.connection.schema
+        mongo_conn: MongoClient = self.get_conn()
+        db = mongo_conn.get_database(mongo_db)
+
+        try:
+            db.create_collection(mongo_collection, **create_kwargs)
+        except CollectionInvalid:
+            if not return_if_exists:
+                raise
+            # Collection already exists – fall through and fetch it.
+
+        return db.get_collection(mongo_collection)
+
     def aggregate(
         self, mongo_collection: str, aggregate_query: list, mongo_db: str | None = None, **kwargs
     ) -> CommandCursor:
@@ -278,8 +310,7 @@ class MongoHook(BaseHook):
 
         if find_one:
             return collection.find_one(query, projection, **kwargs)
-        else:
-            return collection.find(query, projection, **kwargs)
+        return collection.find(query, projection, **kwargs)
 
     def insert_one(
         self, mongo_collection: str, doc: dict, mongo_db: str | None = None, **kwargs
